%global gittag r1rv80
%global classname org.bouncycastle.jce.provider.BouncyCastleProvider

Summary:          Bouncy Castle Cryptography APIs for Java
Name:             bouncycastle
Version:          1.80
Release:          1%{?dist}
License:          MIT
URL:              http://www.bouncycastle.org
Source0:          https://github.com/bcgit/bc-java/archive/%{gittag}.tar.gz
BuildRequires:    javapackages-local
BuildRequires:    ant ant-junit
BuildArch:        noarch
ExclusiveArch:    %{java_arches} noarch
Requires:         javapackages-tools
Requires:         javapackages-filesystem
Requires:         java-headless
Requires(post):   javapackages-tools
Requires(postun): javapackages-tools

Provides:         bcprov = %{version}-%{release}

%description
The Bouncy Castle APIs currently consist of the following:

 - A lightweight cryptography API for Java and C#.
 - A provider for the Java Cryptography Extension (JCE) and the Java Cryptography Architecture (JCA).
 - A provider for the Java Secure Socket Extension (JSSE).
 - A clean room implementation of the JCE 1.2.1.
 - A library for reading and writing encoded ASN.1 objects.
 - Lightweight APIs for TLS (RFC 2246, RFC 4346) and DTLS (RFC 6347/ RFC 4347).
 - Generators for Version 1 and Version 3 X.509 certificates, Version 2 CRLs, and PKCS12 files.
 - Generators for Version 2 X.509 attribute certificates.
 - Generators/Processors for S/MIME and CMS (PKCS7/RFC 3852).
 - Generators/Processors for OCSP (RFC 2560).
 - Generators/Processors for TSP (RFC 3161 & RFC 5544).
 - Generators/Processors for CMP and CRMF (RFC 4210 & RFC 4211).
 - Generators/Processors for OpenPGP (RFC 4880).
 - Generators/Processors for Extended Access Control (EAC).
 - Generators/Processors for Data Validation and Certification Server (DVCS) - RFC 3029.
 - Generators/Processors for DNS-based Authentication of Named Entities (DANE).
 - Generators/Processors for RFC 7030 Enrollment over Secure Transport (EST).
 - A signed jar version suitable for JDK 1.4-1.15 and the Sun JCE.

%package pkix
Summary: Bouncy Castle PKIX, CMS, EAC, TSP, PKCS, OCSP, CMP, and CRMF APIs
Requires:java-headless
Requires:javapackages-filesystem
Requires:bouncycastle
Requires:bouncycastle-util

%description pkix
The Bouncy Castle Java APIs for CMS, PKCS, EAC, TSP, CMP, CRMF, OCSP, and
certificate generation. This jar contains APIs for JDK 1.5 to JDK 1.8. The
APIs can be used in conjunction with a JCE/JCA provider such as the one
provided with the Bouncy Castle Cryptography APIs.

%package pg
Summary: Bouncy Castle OpenPGP API
Requires:java-headless
Requires:javapackages-filesystem
Requires:bouncycastle

%description pg
The Bouncy Castle Java API for handling the OpenPGP protocol. The APIs can be
used in conjunction with a JCE/JCA provider such as the one provided with the
Bouncy Castle Cryptography APIs.

%package mail
Summary: Bouncy Castle S/MIME API
Requires:java-headless
Requires:javapackages-filesystem
Requires:bouncycastle
Requires:bouncycastle-pkix
Requires:bouncycastle-util

%description mail
The Bouncy Castle Java S/MIME APIs for handling S/MIME protocols. The APIs can
be used in conjunction with a JCE/JCA provider such as the one provided with
the Bouncy Castle Cryptography APIs. The JavaMail API and the Java activation
framework will also be needed.

%package tls
Summary: Bouncy Castle JSSE provider and TLS/DTLS API
Requires:java-headless
Requires:javapackages-filesystem
Requires:bouncycastle
Requires:bouncycastle-util

%description tls
The Bouncy Castle Java APIs for TLS and DTLS, including a provider for the
JSSE.

%package util
Summary: Bouncy Castle ASN.1 Extension and Utility APIs
Requires:java-headless
Requires:javapackages-filesystem
Requires:bouncycastle

%description util
The Bouncy Castle Java APIs for ASN.1 extension and utility APIs used to
support bcpkix and bctls.



%prep
%autosetup -p1 -n bc-java-%{gittag}
sed -i -e '/target="build-jmail"/d' ant/jdk15+.xml
sed -i -e '/target="build-lw"/d' ant/jdk15+.xml
sed -i -e '/target="javadoc-lw"/d' ant/jdk15+.xml



%build
export JAVA_HOME=/usr/lib/jvm/java
ant -f ant/jdk18+.xml clean
ant -f ant/jdk18+.xml build-provider
ant -f ant/jdk18+.xml build
cp ./build/artifacts/jdk*/jars/bcprov-ext-jdk*.jar bcprov-ext.jar
cp ./build/artifacts/jdk*/jars/bctest-jdk*.jar bctest.jar
cp ./build/artifacts/jdk*/jars/bcmail-jdk*.jar bcmail.jar
cp ./build/artifacts/jdk*/jars/bctls-jdk*.jar bctls.jar
cp ./build/artifacts/jdk*/jars/bcpg-jdk*.jar bcpg.jar
cp ./build/artifacts/jdk*/jars/bcutil-jdk*.jar bcutil.jar
cp ./build/artifacts/jdk*/jars/bcprov-jdk*.jar bcprov.jar
cp ./build/artifacts/jdk*/jars/bcpkix-jdk*.jar bcpkix.jar



%install
install -dm 755 %{buildroot}%{_sysconfdir}/java/security/security.d
touch %{buildroot}%{_sysconfdir}/java/security/security.d/2000-%{classname}

mkdir -p %{buildroot}%{_datadir}/java/
# main
cp bcprov.jar %{buildroot}%{_datadir}/java/
cp bcprov-ext.jar %{buildroot}%{_datadir}/java/
# mail
cp bcmail.jar %{buildroot}%{_datadir}/java/
# pg
cp bcpg.jar %{buildroot}%{_datadir}/java/
# pkix
cp bcpkix.jar %{buildroot}%{_datadir}/java/
# tls
cp bctls.jar %{buildroot}%{_datadir}/java/
# util
cp bcutil.jar %{buildroot}%{_datadir}/java/



%post
{
  suffix=security/classpath.security
  secfiles="/usr/lib/$suffix /usr/lib64/$suffix"

  for secfile in $secfiles
  do
    [ -f "$secfile" ] || continue

    sed -i '/^security\.provider\./d' "$secfile"

    count=0
    for provider in $(ls /etc/java/security/security.d)
    do
      count=$((count + 1))
      echo "security.provider.${count}=${provider#*-}" >> "$secfile"
    done
  done
} || :

%postun
if [ "$1" -eq 0 ] ; then

  {
    suffix=security/classpath.security
    secfiles="/usr/lib/$suffix /usr/lib64/$suffix"

    for secfile in $secfiles
    do
      [ -f "$secfile" ] || continue

      sed -i '/^security\.provider\./d' "$secfile"

      count=0
      for provider in $(ls /etc/java/security/security.d)
      do
        count=$((count + 1))
        echo "security.provider.${count}=${provider#*-}" >> "$secfile"
      done
    done
  } || :

fi



%files
%license build/artifacts/jdk*/bcprov-jdk*/LICENSE.html
%doc docs/ *.html
%{_sysconfdir}/java/security/security.d/2000-%{classname}
%{_datadir}/java/bcprov.jar
%{_datadir}/java/bcprov-ext.jar

%files pkix
%license build/artifacts/jdk*/bcpkix-jdk*/LICENSE.html
%{_datadir}/java/bcpkix.jar

%files pg
%license build/artifacts/jdk*/bcpg-jdk*/LICENSE.html
%{_datadir}/java/bcpg.jar

%files mail
%license build/artifacts/jdk*/bcmail-jdk*/LICENSE.html
%{_datadir}/java/bcmail.jar

%files tls
%license build/artifacts/jdk*/bctls-jdk*/LICENSE.html
%{_datadir}/java/bctls.jar

%files util
%license build/artifacts/jdk*/bcutil-jdk*/LICENSE.html
%{_datadir}/java/bcutil.jar



%changelog
* Mon Jan 20 2025 Zhao Zhen <jeremiazhao@tencent.com> - 1.80-1
- updated to upstream 1.80
- fixed CVE-2023-33201 CVE-2024-34447 CVE-2024-30171
- rewrite building script

* Thu Sep 26 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.70-5
- Rebuilt for clarifying the packages requirement in BaseOS and AppStream

* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.70-4
- Rebuilt for loongarch release

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.70-3
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.70-2
- Rebuilt for OpenCloudOS Stream 23.05

* Tue Apr 25 2023 cunshunxia <cunshunxia@tencent.com> - 1.70-1
- initial build
